summaryrefslogtreecommitdiffstats
path: root/c/src/lib/libcpu/mips/timer/timer.c
diff options
context:
space:
mode:
Diffstat (limited to 'c/src/lib/libcpu/mips/timer/timer.c')
-rw-r--r--c/src/lib/libcpu/mips/timer/timer.c28
1 files changed, 9 insertions, 19 deletions
diff --git a/c/src/lib/libcpu/mips/timer/timer.c b/c/src/lib/libcpu/mips/timer/timer.c
index 0db65238eb..86b45ce9cb 100644
--- a/c/src/lib/libcpu/mips/timer/timer.c
+++ b/c/src/lib/libcpu/mips/timer/timer.c
@@ -21,8 +21,8 @@
*
* This file manages the benchmark timer used by the RTEMS Timing Test
* Suite. Each measured time period is demarcated by calls to
* Timer_initialize() and Read_timer(). Read_timer() usually returns
* the number of microseconds since Timer_initialize() exitted.
*
* NOTE: It is important that the timer start/stop overhead be
* determined when porting or modifying this code.
@@ -52,10 +52,10 @@
extern uint32_t mips_read_timer( void );
-static rtems_boolean Timer_driver_Find_average_overhead;
+static rtems_boolean benchmark_timer_find_average_overhead;
static uint32_t Timer_initial_value = 0;
-void Timer_initialize( void )
+void benchmark_timer_initialize( void )
{
Timer_initial_value = mips_read_timer();
/*
@@ -66,7 +66,7 @@ void Timer_initialize( void )
}
/*
* The following controls the behavior of Read_timer().
*
* AVG_OVEREHAD is the overhead for starting and stopping the timer. It
* is usually deducted from the number returned.
@@ -80,7 +80,7 @@ void Timer_initialize( void )
/* This value is in cycles. */
#define LEAST_VALID 1 /* Don't trust a clicks value lower than this */
-int Read_timer( void )
+int benchmark_timer_read( void )
{
uint64_t clicks;
uint32_t total;
@@ -107,7 +107,7 @@ int Read_timer( void )
total = clicks;
#endif
- if ( Timer_driver_Find_average_overhead == 1 )
+ if ( benchmark_timer_find_average_overhead == 1 )
return total; /* in # cycles units */
else {
if ( total < LEAST_VALID )
@@ -119,19 +119,9 @@ int Read_timer( void )
}
}
-/*
- * Empty function call used in loops to measure basic cost of looping
- * in Timing Test Suite.
- */
-
-rtems_status_code Empty_function( void )
-{
- return RTEMS_SUCCESSFUL;
-}
-
-void Set_find_average_overhead(
+void benchmark_timer_disable_subtracting_average_overhead(
rtems_boolean find_flag
)
{
- Timer_driver_Find_average_overhead = find_flag;
+ benchmark_timer_find_average_overhead = find_flag;
}
@@ -21,8 +21,8 @@
* This file manages the benchmark timer used by the RTEMS Timing Test
* Suite. Each measured time period is demarcated by calls to
- * Timer_initialize() and Read_timer(). Read_timer() usually returns
- * the number of microseconds since Timer_initialize() exitted.
+ * benchmark_timer_initialize() and benchmark_timer_read(). benchmark_timer_read() usually returns
+ * the number of microseconds since benchmark_timer_initialize() exitted.
*
* NOTE: It is important that the timer start/stop overhead be
@@ -66,7 +66,7 @@ void Timer_initialize( void )
}
/*
- * The following controls the behavior of Read_timer().
+ * The following controls the behavior of benchmark_timer_read().
*
* AVG_OVEREHAD is the overhead for starting and stopping the timer. It